@@ -10,7 +10,7 @@ from datetime import datetime, timezone
 from pathlib import Path
 from typing import get_args
 
-from ramalama.config import COLOR_OPTIONS, SUPPORTED_RUNTIMES
+from ramalama.config import COLOR_OPTIONS, SUPPORTED_ENGINES, SUPPORTED_RUNTIMES
 
 # if autocomplete doesn't exist, just do nothing, don't break
 try:
@@ -28,7 +28,13 @@ from ramalama.chat import default_prefix
 from ramalama.common import accel_image, get_accel, perror
 from ramalama.config import CONFIG, coerce_to_bool, load_file_config
 from ramalama.logger import configure_logger, logger
-from ramalama.model import MODEL_TYPES, NoGGUFModelFileFound, SafetensorModelNotSupported, trim_model_name
+from ramalama.model import (
+    MODEL_TYPES,
+    NoGGUFModelFileFound,
+    NoRefFileFound,
+    SafetensorModelNotSupported,
+    trim_model_name,
+)
 from ramalama.model_factory import ModelFactory, New
 from ramalama.model_inspect.error import ParseError
 from ramalama.model_store.global_store import GlobalModelStore
@@ -109,6 +115,19 @@ def local_images(prefix, parsed_args, **kwargs):
     return engine.images(parsed_args)
 
 
+def available_metadata(prefix, parsed_args, **kwargs):
+    if parsed_args.MODEL:
+        # shotnames resolution has not been applied for auto-completion
+        # Therefore it needs to be done explicitly here in order to support it
+        resolved_model = shortnames.resolve(parsed_args.MODEL)
+        if not resolved_model:
+            resolved_model = parsed_args.MODEL
+
+        metadata = New(resolved_model, parsed_args).inspect_metadata()
+        return [field for field in metadata.keys() if field.startswith(parsed_args.get)]
+    return []
+
+
 class ArgumentParserWithDefaults(argparse.ArgumentParser):
     def add_argument(self, *args, help=None, default=None, completer=None, **kwargs):
         if help is not None:
@@ -205,6 +224,7 @@ def configure_arguments(parser):
         "--engine",
         dest="engine",
         default=CONFIG.engine,
+        choices=get_args(SUPPORTED_ENGINES),
         help="""run RamaLama using the specified container engine.
 The RAMALAMA_CONTAINER_ENGINE environment variable modifies default behaviour.""",
     )
@@ -258,6 +278,7 @@ def configure_subcommands(parser):
     serve_parser(subparsers)
     stop_parser(subparsers)
     version_parser(subparsers)
+    daemon_parser(subparsers)
 
 
 def parse_arguments(parser):
@@ -755,10 +776,19 @@ def runtime_options(parser, command):
         )
     parser.add_argument("--authfile", help="path of the authentication file")
     if command in ["run", "perplexity", "serve"]:
+        parser.add_argument(
+            "--cache-reuse",
+            dest="cache_reuse",
+            type=int,
+            default=CONFIG.cache_reuse,
+            help="min chunk size to attempt reusing from the cache via KV shifting",
+            completer=suppressCompleter,
+        )
         parser.add_argument(
             "-c",
             "--ctx-size",
             dest="context",
+            type=int,
             default=CONFIG.ctx_size,
             help="size of the prompt context (0 = loaded from model)",
             completer=suppressCompleter,
@@ -766,6 +796,7 @@ def runtime_options(parser, command):
         parser.add_argument(
             "--max-model-len",
             dest="context",
+            type=int,
             default=CONFIG.ctx_size,
             help=argparse.SUPPRESS,
             completer=suppressCompleter,
@@ -775,7 +806,11 @@ def runtime_options(parser, command):
             "-d", "--detach", action="store_true", dest="detach", help="run the container in detached mode"
         )
     parser.add_argument(
-        "--device", dest="device", action='append', type=str, help="device to leak in to the running container"
+        "--device",
+        dest="device",
+        action='append',
+        type=str,
+        help="device to leak in to the running container (or 'none' to pass no device)",
     )
     parser.add_argument(
         "--env",
@@ -1087,6 +1122,107 @@ def stop_container(args):
         engine.stop_container(args, i)
 
 
+def daemon_parser(subparsers):
+    parser: ArgumentParserWithDefaults = subparsers.add_parser("daemon", help="daemon operations")
+    parser.set_defaults(func=lambda _: parser.print_help())
+
+    daemon_parsers = parser.add_subparsers(dest="daemon_command")
+
+    start_parser = daemon_parsers.add_parser("start")
+    start_parser.add_argument(
+        "--image",
+        default=accel_image(CONFIG),
+        help="OCI container image to run with the specified AI model",
+        action=OverrideDefaultAction,
+        completer=local_images,
+    )
+    start_parser.add_argument(
+        "--pull",
+        dest="pull",
+        type=str,
+        default=CONFIG.pull,
+        choices=["always", "missing", "never", "newer"],
+        help='pull image policy',
+    )
+    start_parser.add_argument(
+        "--host",
+        default=CONFIG.host,
+        help="IP address to listen",
+        completer=suppressCompleter,
+    )
+    start_parser.add_argument(
+        "-p",
+        "--port",
+        type=parse_port_option,
+        default=CONFIG.port,
+        help="port for AI Model server to listen on",
+        completer=suppressCompleter,
+    )
+    start_parser.set_defaults(func=daemon_start_cli)
+
+    run_parser = daemon_parsers.add_parser("run")
+    run_parser.add_argument(
+        "--host",
+        default=CONFIG.host,
+        help="IP address to listen",
+        completer=suppressCompleter,
+    )
+    run_parser.add_argument(
+        "-p",
+        "--port",
+        type=parse_port_option,
+        default=CONFIG.port,
+        help="port for AI Model server to listen on",
+        completer=suppressCompleter,
+    )
+    run_parser.set_defaults(func=daemon_run_cli)
+
+
+def daemon_start_cli(args):
+    from ramalama.common import exec_cmd
+
+    daemon_cmd = []
+    daemon_model_store_dir = args.store
+    is_daemon_in_container = args.container and args.engine in get_args(SUPPORTED_ENGINES)
+
+    if is_daemon_in_container:
+        # If run inside a container, map the model store to the container internal directory
+        daemon_model_store_dir = "/ramalama/models"
+
+        daemon_cmd += [
+            "podman",
+            "run",
+            "--pull",
+            args.pull,
+            "-d",
+            "-p",
+            f"{args.port}:8080",
+            "-v",
+            f"{args.store}:{daemon_model_store_dir}",
+            args.image,
+        ]
+
+    daemon_cmd += [
+        "ramalama",
+        "--store",
+        daemon_model_store_dir,
+        "daemon",
+        "run",
+        "--port",
+        "8080" if is_daemon_in_container else args.port,
+        "--host",
+        CONFIG.host if is_daemon_in_container else args.host,
+    ]
+
+    exec_cmd(daemon_cmd)
+
+
+def daemon_run_cli(args):
+    from ramalama.daemon.daemon import run
+
+    run(host=args.host, port=int(args.port), model_store_path=args.store)
+
+
 def version_parser(subparsers):
     parser = subparsers.add_parser("version", help="display version of RamaLama")
     parser.set_defaults(func=print_version)
@@ -1240,6 +1376,14 @@ def perplexity_cli(args):
 def inspect_parser(subparsers):
     parser = subparsers.add_parser("inspect", help="inspect an AI Model")
     parser.add_argument("--all", dest="all", action="store_true", help="display all available information of AI Model")
+    parser.add_argument(
+        "--get",
+        dest="get",
+        type=str,
+        default="",
+        completer=available_metadata,
+        help="display specific metadata field of AI Model",
+    )
     parser.add_argument("--json", dest="json", action="store_true", help="display AI Model information in JSON format")
     parser.add_argument("MODEL", completer=local_models)  # positional argument
     parser.set_defaults(func=inspect_cli)
@@ -1248,7 +1392,7 @@ def inspect_parser(subparsers):
 def inspect_cli(args):
     args.pull = "never"
     model = New(args.MODEL, args)
-    model.inspect(args)
+    model.inspect(args.all, args.get == "all", args.get, args.json, args.dryrun)
 
 
 def main():
@@ -1277,20 +1421,14 @@ def main():
         eprint(f"pulling {e.geturl()} failed: {e}", errno.EINVAL)
     except HelpException:
         parser.print_help()
-    except IndexError as e:
+    except (ConnectionError, IndexError, KeyError, ValueError, NoRefFileFound) as e:
         eprint(e, errno.EINVAL)
-    except KeyError as e:
-        eprint(e, 1)
     except NotImplementedError as e:
-        eprint(e, errno.ENOTSUP)
+        eprint(e, errno.ENOSYS)
     except subprocess.CalledProcessError as e:
         eprint(e, e.returncode)
     except KeyboardInterrupt:
         sys.exit(0)
-    except ConnectionError as e:
-        eprint(e, errno.EINVAL)
-    except ValueError as e:
-        eprint(e, errno.EINVAL)
     except IOError as e:
         eprint(e, errno.EIO)
     except ParseError as e:
@@ -1301,7 +1439,7 @@ def main():
 $ ramalama convert --gguf=<quantization> {args.model} <oci-name>
 $ ramalama run <oci-name>
 """,
-            errno.EMEDIUMTYPE,
+            errno.ENOTSUP,
         )
     except NoGGUFModelFileFound:
-        eprint(f"No GGUF model file found for downloaded model '{args.model}'", errno.ENOMEDIUM)
+        eprint(f"No GGUF model file found for downloaded model '{args.model}'", errno.ENOENT)
