@@ -7,7 +7,7 @@ import subprocess
 import sys
 import time
 from abc import ABC, abstractmethod
-from typing import Optional
+from typing import Any, Dict, Optional
 
 import ramalama.chat as chat
 from ramalama.common import (
@@ -22,9 +22,10 @@ from ramalama.common import (
     perror,
     set_accel_env_vars,
 )
+from ramalama.compose import Compose
 from ramalama.config import CONFIG, DEFAULT_PORT, DEFAULT_PORT_RANGE
 from ramalama.console import should_colorize
-from ramalama.engine import Engine, dry_run, wait_for_healthy
+from ramalama.engine import Engine, dry_run, is_healthy, wait_for_healthy
 from ramalama.kube import Kube
 from ramalama.logger import logger
 from ramalama.model_inspect.base_info import ModelInfoBase
@@ -272,8 +273,8 @@ class Model(ModelBase):
         if not ref_file.chat_templates:
             return None
 
-        # Use the first chat template file
-        chat_template_file = ref_file.chat_templates[0]
+        # Use the last chat template file (may have been go template converted to jinja)
+        chat_template_file = ref_file.chat_templates[-1]
         if use_container or should_generate:
             return os.path.join(MNT_DIR, chat_template_file.name)
         return self.model_store.get_blob_file_path(chat_template_file.hash)
@@ -387,7 +388,7 @@ class Model(ModelBase):
         # The Run command will first launch a daemonized service
         # and run chat to communicate with it.
 
-        args.port = compute_serving_port(args, quiet=args.debug)
+        args.port = compute_serving_port(args, quiet=not args.debug)
         if args.container:
             args.name = self.get_container_name(args)
 
@@ -435,7 +436,7 @@ class Model(ModelBase):
 
         if not args.dryrun:
             try:
-                wait_for_healthy(args)
+                wait_for_healthy(args, is_healthy)
             except subprocess.TimeoutExpired as e:
                 logger.error(f"Failed to serve model {self.model_name}, for ramalama run command")
                 logger.error(f"{e}: logs: {e.output}")
@@ -651,18 +652,19 @@ class Model(ModelBase):
                 exec_args += ["--chat-template-file", chat_template_path]
 
         if should_colorize():
-            exec_args += ["--log-colors"]
+            exec_args += ["--log-colors", "on"]
 
         exec_args += [
             "--alias",
             self.model,
-            "--ctx-size",
-            f"{args.context}",
             "--temp",
             f"{args.temp}",
             "--cache-reuse",
-            "256",
+            f"{args.cache_reuse}",
         ]
+        if args.context > 0:
+            exec_args += ["--ctx-size", f"{args.context}"]
+
         exec_args += args.runtime_args
 
         if draft_model_path:
@@ -680,7 +682,7 @@ class Model(ModelBase):
             exec_args.extend(["--no-webui"])
 
         if check_nvidia() or check_metal(args):
-            exec_args.extend(["--flash-attn"])
+            exec_args.extend(["--flash-attn", "on"])
         return exec_args
 
     def mlx_serve(self, args):
@@ -770,6 +772,15 @@ class Model(ModelBase):
                 exec_args,
                 args.generate.output_dir,
             )
+        elif args.generate.gen_type == "compose":
+            self.compose(
+                (model_src_path, model_dest_path),
+                (chat_template_src_path, chat_template_dest_path),
+                (mmproj_src_path, mmproj_dest_path),
+                args,
+                exec_args,
+                args.generate.output_dir,
+            )
 
     def execute_command(self, exec_args, args):
         try:
@@ -778,7 +789,7 @@ class Model(ModelBase):
             if args.dryrun:
                 dry_run(exec_args)
                 return
-            exec_cmd(exec_args, stdout2null=args.noout)
+            exec_cmd(exec_args, stdout2null=args.noout, stderr2null=args.noout)
         except FileNotFoundError as e:
             if args.container:
                 raise NotImplementedError(
@@ -824,23 +835,51 @@ class Model(ModelBase):
         kube = Kube(self.model_name, model_paths, chat_template_paths, mmproj_paths, args, exec_args)
         kube.generate().write(output_dir)
 
-    def inspect(self, args) -> None:
-        self.ensure_model_exists(args)
+    def compose(self, model_paths, chat_template_paths, mmproj_paths, args, exec_args, output_dir):
+        compose = Compose(self.model_name, model_paths, chat_template_paths, mmproj_paths, args, exec_args)
+        compose.generate().write(output_dir)
 
+    def inspect_metadata(self) -> Dict[str, Any]:
+        model_path = self._get_entry_model_path(False, False, False)
+        if GGUFInfoParser.is_model_gguf(model_path):
+            return GGUFInfoParser.parse_metadata(model_path).data
+        return {}
+
+    def inspect(
+        self,
+        show_all: bool = False,
+        show_all_metadata: bool = False,
+        get_field: str = "",
+        as_json: bool = False,
+        dryrun: bool = False,
+    ) -> None:
         model_name = self.filename
         model_registry = self.type.lower()
-        model_path = self._get_entry_model_path(False, False, args.dryrun)
+        model_path = self._get_entry_model_path(False, False, dryrun)
 
         if GGUFInfoParser.is_model_gguf(model_path):
-            gguf_info: GGUFModelInfo = GGUFInfoParser.parse(model_name, model_registry, model_path)
-            print(gguf_info.serialize(json=args.json, all=args.all))
-            return
+            if not show_all_metadata and get_field == "":
+                gguf_info: GGUFModelInfo = GGUFInfoParser.parse(model_name, model_registry, model_path)
+                print(gguf_info.serialize(json=as_json, all=show_all))
+                return
+
+            metadata = GGUFInfoParser.parse_metadata(model_path)
+            if show_all_metadata:
+                print(metadata.serialize(json=as_json))
+                return
+            elif get_field != "":  # If a specific field is requested, print only that field
+                field_value = metadata.get(get_field)
+                if field_value is None:
+                    raise KeyError(f"Field '{get_field}' not found in GGUF model metadata")
+                print(field_value)
+                return
+
         if SafetensorInfoParser.is_model_safetensor(model_name):
             safetensor_info: SafetensorModelInfo = SafetensorInfoParser.parse(model_name, model_registry, model_path)
-            print(safetensor_info.serialize(json=args.json, all=args.all))
+            print(safetensor_info.serialize(json=as_json, all=show_all))
             return
 
-        print(ModelInfoBase(model_name, model_registry, model_path).serialize(json=args.json))
+        print(ModelInfoBase(model_name, model_registry, model_path).serialize(json=as_json))
 
     def print_pull_message(self, model_name):
         model_name = trim_model_name(model_name)
