@@ -12,6 +12,7 @@ class Quadlet:
         model_name: str,
         model_paths: Tuple[str, str],
         chat_template_paths: Optional[Tuple[str, str]],
+        mmproj_path: Optional[Tuple[str, str]],
         args,
         exec_args,
     ):
@@ -19,9 +20,13 @@ class Quadlet:
         self.src_chat_template_path, self.dest_chat_template_path = (
             chat_template_paths if chat_template_paths is not None else ("", "")
         )
+        self.src_mmproj_path, self.dest_mmproj_path = mmproj_path if mmproj_path is not None else ("", "")
 
-        self.ai_image = model_name
-        self.src_model_path = self.src_model_path.removeprefix("oci://")
+        if self.src_model_path.startswith("oci://"):
+            self.src_model_path = self.src_model_path.removeprefix("oci://")
+            self.ai_image = self.src_model_path
+        else:
+            self.ai_image = model_name
         if getattr(args, "name", None):
             self.name = args.name
         else:
@@ -65,8 +70,12 @@ class Quadlet:
             if not getattr(self.args, "nocapdrop", False):
                 quadlet_file.add("Container", "DropCapability", "all")
                 quadlet_file.add("Container", "NoNewPrivileges", "true")
-
+        if add_to_units := getattr(self.args, "add_to_unit", None):
+            for unit in add_to_units:
+                section, key, value = unit.split(":", 2)
+                quadlet_file.add(section, key, value)
         self._gen_chat_template_volume(quadlet_file)
+        self._gen_mmproj_volume(quadlet_file)
         self._gen_env(quadlet_file)
         self._gen_name(quadlet_file)
         self._gen_port(quadlet_file)
@@ -83,13 +92,21 @@ class Quadlet:
         return files
 
     def _gen_chat_template_volume(self, quadlet_file: UnitFile):
-        if os.path.exists(self.src_chat_template_path):
+        if self.src_chat_template_path and os.path.exists(self.src_chat_template_path):
             quadlet_file.add(
                 "Container",
                 "Mount",
                 f"type=bind,src={self.src_chat_template_path},target={self.dest_chat_template_path},ro,Z",
             )
 
+    def _gen_mmproj_volume(self, quadlet_file: UnitFile):
+        if self.src_mmproj_path and os.path.exists(self.src_mmproj_path):
+            quadlet_file.add(
+                "Container",
+                "Mount",
+                f"type=bind,src={self.src_mmproj_path},target={self.dest_mmproj_path},ro,Z",
+            )
+
     def _gen_env(self, quadlet_file: UnitFile):
         env_var_string = ""
         for k, v in get_accel_env_vars().items():
@@ -137,7 +154,8 @@ class Quadlet:
 
     def _gen_port(self, quadlet_file: UnitFile):
         if getattr(self.args, "port", "") != "":
-            quadlet_file.add("Container", "PublishPort", f"{self.args.port}:{self.args.port}")
+            host = getattr(self.args, "host", None) or "0.0.0.0"
+            quadlet_file.add("Container", "PublishPort", f"{host}:{self.args.port}:{self.args.port}")
 
     def _gen_rag_volume(self, quadlet_file: UnitFile):
         files: list[UnitFile] = []
